==> kadu_1.2.orig.tar.bz2: kadu-1.2/plugins/filedesc/translations/filedesc_en.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="en" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>FileDesc</source>
        <translation>FileDesc</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>File with description to synchronize</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Enter here a file, which will contain descriptions to refresh by module.</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>If you choose status without description, module will set it automatically to similar but with description</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Allow other descriptions</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Allows you to set some custom description manualy, until file contents does not change</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Behavior</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Always add description to status</source>
        <translation>Always add description to status</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/filedesc/translations/filedesc_en.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en">
<context>
    <name>@default</name>
    <message>
        <source>FileDesc</source>
        <translation>FileDesc</translation>
    </message>
    <message>
        <source>File with description to synchronize</source>
        <translation>File with description to synchronize</translation>
    </message>
    <message>
        <source>Enter here a file, which will contain descriptions to refresh by module.</source>
        <translation>Enter here a file, which will contain descriptions to refresh by module.</translation>
    </message>
    <message>
        <source>If you choose status without description, module will set it automatically to similar but with description</source>
        <translation>If you choose status without description, module will set it automatically to similar but with description</translation>
    </message>
    <message>
        <source>Allow other descriptions</source>
        <translation>Allow other descriptions</translation>
    </message>
    <message>
        <source>Allows you to set some custom description manualy, until file contents does not change</source>
        <translation>Allows you to set some custom description manualy, until file contents does not change</translation>
    </message>
    <message>
        <source>Behavior</source>
        <translation>Behavior</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Description</translation>
    </message>
    <message>
        <source>Always add description to status</source>
        <translation>Always add description to status</translation>
    </message>
</context>
</TS>
